@@ -1,5 +1,6 @@
 import unittest
 
+from openshift import Context
 from .apiobject import APIObject
 
 
@@ -12,6 +13,12 @@ class TestModel(unittest.TestCase):
         self.assertEqual(obj.as_json(), '{}')
         self.assertIsNone(obj.context.project_name)
 
+    def test_context(self):
+        context = Context()
+        context.project_name = "my-project"
+        obj = APIObject(context=context)
+        self.assertEqual(obj.context.project_name, context.project_name)
+
 
 if __name__ == '__main__':
     unittest.main()
